@@ -28,18 +28,18 @@
 
 #include "ui_SwitchingTabBase.h"
 
-#include <utils/d_ptr_implementation.h>
 #include <KActivities/Consumer>
+#include <utils/d_ptr_implementation.h>
 
-class SwitchingTab::Private : public Ui::SwitchingTabBase {
+class SwitchingTab::Private : public Ui::SwitchingTabBase
+{
 public:
     KActivityManagerdSettings *mainConfig;
 
     KActionCollection *mainActionCollection;
     KActivities::Consumer activities;
 
-    void createAction(const QString &actionName, const QString &actionText,
-                      const QList<QKeySequence> &defaultSequence)
+    void createAction(const QString &actionName, const QString &actionText, const QList<QKeySequence> &defaultSequence)
     {
         auto action = mainActionCollection->addAction(actionName);
         action->setProperty("isConfigurationAction", true);
@@ -49,8 +49,8 @@ public:
     }
 
     Private()
-        : mainConfig(new KActivityManagerdSettings),
-          mainActionCollection(nullptr)
+        : mainConfig(new KActivityManagerdSettings)
+        , mainActionCollection(nullptr)
     {
     }
 };
@@ -66,12 +66,8 @@ SwitchingTab::SwitchingTab(QWidget *parent)
     d->mainActionCollection->setComponentDisplayName(i18n("Activity switching"));
     d->mainActionCollection->setConfigGlobal(true);
 
-    d->createAction(QStringLiteral("next activity"),
-                    i18nc("@action", "Walk through activities"),
-                    { Qt::META + Qt::Key_Tab });
-    d->createAction(QStringLiteral("previous activity"),
-                    i18nc("@action", "Walk through activities (Reverse)"),
-                    { Qt::META + Qt::SHIFT + Qt::Key_Tab } );
+    d->createAction(QStringLiteral("next activity"), i18nc("@action", "Walk through activities"), {Qt::META | Qt::Key_Tab});
+    d->createAction(QStringLiteral("previous activity"), i18nc("@action", "Walk through activities (Reverse)"), {Qt::META | Qt::SHIFT | Qt::Key_Tab});
 
     d->scActivities->setActionTypes(KShortcutsEditor::GlobalAction);
     d->scActivities->addCollection(d->mainActionCollection);
@@ -88,16 +84,13 @@ KCoreConfigSkeleton *SwitchingTab::mainConfig()
 
 void SwitchingTab::shortcutChanged(const QKeySequence &sequence)
 {
-    QString actionName = sender()
-                             ? sender()->property("shortcutAction").toString()
-                             : QString();
+    QString actionName = sender() ? sender()->property("shortcutAction").toString() : QString();
 
-    if (actionName.isEmpty()) return;
+    if (actionName.isEmpty())
+        return;
 
     auto action = d->mainActionCollection->action(actionName);
 
-    KGlobalAccel::self()->setShortcut(action, { sequence },
-                                      KGlobalAccel::NoAutoloading);
+    KGlobalAccel::self()->setShortcut(action, {sequence}, KGlobalAccel::NoAutoloading);
     d->mainActionCollection->writeSettings();
 }
-
