@@ -20,6 +20,7 @@
 
 #include <QCommandLineParser>
 #include <QDebug>
+#include <QProcess>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QX11Info>
@@ -27,6 +28,8 @@
 #include <KAboutData>
 #include <KLocalizedString>
 
+#include <memory>
+
 #include "application.h"
 #include "config-workspace.h"
 #include "doodad.h"
@@ -70,13 +73,13 @@ int main(int argc, char *argv[])
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
 
-    QCommandLineOption modelOption(QStringList { "m", "model" }, {}, QStringLiteral("MODEL"));
+    QCommandLineOption modelOption(QStringList{"m", "model"}, {}, QStringLiteral("MODEL"));
     parser.addOption(modelOption);
-    QCommandLineOption layoutOption(QStringList { "l", "layout" }, {}, QStringLiteral("LAYOUT"));
+    QCommandLineOption layoutOption(QStringList{"l", "layout"}, {}, QStringLiteral("LAYOUT"));
     parser.addOption(layoutOption);
-    QCommandLineOption variantOption(QStringList { "a", "variant" }, {}, QStringLiteral("VARIANT"));
+    QCommandLineOption variantOption(QStringList{"a", "variant"}, {}, QStringLiteral("VARIANT"));
     parser.addOption(variantOption);
-    QCommandLineOption optionsOption(QStringList { "o", "options" }, {}, QStringLiteral("OPTIONS"));
+    QCommandLineOption optionsOption(QStringList{"o", "options"}, {}, QStringLiteral("OPTIONS"));
     parser.addOption(optionsOption);
     parser.process(app);
     aboutData.processCommandLine(&parser);
@@ -106,32 +109,57 @@ int main(int argc, char *argv[])
                                       qgetenv("LOCALE").data(),
                                       True,
                                       True);
+
     Q_ASSERT(rules);
-    QSharedPointer<XkbRF_RulesRec> rulesCleanup(rules, [](XkbRF_RulesPtr obj) {
+    std::unique_ptr<XkbRF_RulesRec, std::function<void(XkbRF_RulesPtr)>> rulesCleanup(rules, [](XkbRF_RulesPtr obj) {
         XkbRF_Free(obj, True);
     });
 
     XkbComponentNamesRec componentNames;
     memset(&componentNames, 0, sizeof(XkbComponentNamesRec));
-
     XkbRF_GetComponents(rules, &varDefs, &componentNames);
 
-    XkbDescPtr xkb = XkbGetKeyboardByName(QX11Info::display(),
-                                          XkbUseCoreKbd,
-                                          &componentNames,
-                                          0,
-                                          XkbGBN_GeometryMask |
-                                          XkbGBN_KeyNamesMask |
-                                          XkbGBN_OtherNamesMask |
-                                          XkbGBN_ClientSymbolsMask |
-                                          XkbGBN_IndicatorMapMask,
-                                          false);
-    Q_ASSERT(xkb);
-    QSharedPointer<XkbDescRec> xkbCleanup(xkb, [](XkbDescPtr obj) {
-        XkbFreeKeyboard(obj, 0, True);
-    });
+    QString errorDescription;
+    QString errorDetails;
+    std::unique_ptr<Geometry> geometry;
 
-    Geometry geometry(xkb->geom, xkb);
+    XkbDescPtr xkb =
+        XkbGetKeyboardByName(QX11Info::display(),
+                             XkbUseCoreKbd,
+                             &componentNames,
+                             0,
+                             XkbGBN_GeometryMask | XkbGBN_KeyNamesMask | XkbGBN_OtherNamesMask | XkbGBN_ClientSymbolsMask | XkbGBN_IndicatorMapMask,
+                             false);
+    if (!xkb) {
+        QProcess setxkbmap;
+        QProcess xkbcomp;
+
+        setxkbmap.setStandardOutputProcess(&xkbcomp);
+        xkbcomp.setProcessChannelMode(QProcess::MergedChannels); // combine in single channel
+        setxkbmap.start(QStringLiteral("setxkbmap"),
+                        {QStringLiteral("-print"),
+                         QStringLiteral("-model"),
+                         model,
+                         QStringLiteral("-layout"),
+                         layout,
+                         QStringLiteral("-variant"),
+                         variant,
+                         QStringLiteral("-option"),
+                         options});
+        xkbcomp.start(QStringLiteral("xkbcomp"), {QStringLiteral("-")});
+        setxkbmap.waitForFinished();
+        xkbcomp.waitForFinished();
+
+        errorDescription = i18nc("@label",
+                                 "The keyboard geometry failed to load."
+                                 " This often indicates that the selected model does not support a specific layout"
+                                 " or layout variant."
+                                 " This problem will likely also present when you try to use this combination of model, layout and variant.");
+        errorDetails = xkbcomp.readAllStandardOutput();
+    } else {
+        Q_ASSERT(xkb);
+        geometry.reset(new Geometry(xkb->geom, xkb));
+    }
 
     // Register the doodads so we can perform easy type checks with them
     // and determine how to render the individual object.
@@ -150,13 +178,21 @@ int main(int argc, char *argv[])
     // faster). Constructing our QObjects takes 1ms.
     QQmlApplicationEngine engine;
     const QUrl url(QStringLiteral("qrc:/qml/main.qml"));
-    QObject::connect(&engine, &QQmlApplicationEngine::objectCreated,
-                     &app, [url](QObject *obj, const QUrl &objUrl) {
-        if (!obj && url == objUrl)
-            QCoreApplication::exit(-1);
-    }, Qt::QueuedConnection);
-    engine.rootContext()->setContextProperty("geometry", &geometry);
+    QObject::connect(
+        &engine,
+        &QQmlApplicationEngine::objectCreated,
+        &app,
+        [url](QObject *obj, const QUrl &objUrl) {
+            if (!obj && url == objUrl)
+                QCoreApplication::exit(-1);
+        },
+        Qt::QueuedConnection);
+    engine.rootContext()->setContextProperty("geometry", geometry.get());
+    engine.rootContext()->setContextProperty("errorDescription", errorDescription);
+    engine.rootContext()->setContextProperty("errorDetails", errorDetails);
     engine.load(url);
 
     return app.exec();
 }
+
+#include "main.moc"
