@@ -348,7 +348,7 @@ void ShortcutsModelPrivate::slotDataChanged(const QModelIndex &from, const QMode
     }
     const QModelIndex myFrom = q->mapFromSource(from);
     const QModelIndex myTo = q->mapFromSource(to);
-    emit q->dataChanged(myFrom, myTo, roles);
+    Q_EMIT q->dataChanged(myFrom, myTo, roles);
 }
 
 void ShortcutsModelPrivate::slotSourceLayoutAboutToBeChanged(const QList<QPersistentModelIndex> &sourceParents, QAbstractItemModel::LayoutChangeHint hint)
@@ -365,7 +365,7 @@ void ShortcutsModelPrivate::slotSourceLayoutAboutToBeChanged(const QList<QPersis
         parents << mappedParent;
     }
 
-    emit q->layoutAboutToBeChanged(parents, hint);
+    Q_EMIT q->layoutAboutToBeChanged(parents, hint);
 
     const QModelIndexList persistentIndexList = q->persistentIndexList();
     layoutChangePersistentIndexes.reserve(persistentIndexList.size());
@@ -401,7 +401,7 @@ void ShortcutsModelPrivate::slotSourceLayoutChanged(const QList<QPersistentModel
         Q_ASSERT(mappedParent.isValid());
         parents << mappedParent;
     }
-    emit q->layoutChanged(parents, hint);
+    Q_EMIT q->layoutChanged(parents, hint);
 }
 
 void ShortcutsModelPrivate::slotModelAboutToBeReset()
