@@ -20,7 +20,8 @@
 #include <KConfigGroup>
 #include <KSharedConfig>
 
-template<> bool LibinputSettings::load(QString key, bool defVal)
+template<>
+bool LibinputSettings::load(QString key, bool defVal)
 {
     KSharedConfig::Ptr kcminputPtr = KSharedConfig::openConfig("kcminputrc");
     KConfigGroup group(kcminputPtr, "Mouse");
@@ -28,7 +29,8 @@ template<> bool LibinputSettings::load(QString key, bool defVal)
     return group.readEntry(key, defVal);
 }
 
-template<> qreal LibinputSettings::load(QString key, qreal defVal)
+template<>
+qreal LibinputSettings::load(QString key, qreal defVal)
 {
     KSharedConfig::Ptr kcminputPtr = KSharedConfig::openConfig("kcminputrc");
     KConfigGroup group(kcminputPtr, "Mouse");
@@ -36,7 +38,8 @@ template<> qreal LibinputSettings::load(QString key, qreal defVal)
     return group.readEntry(key, defVal);
 }
 
-template<> void LibinputSettings::save(QString key, bool val)
+template<>
+void LibinputSettings::save(QString key, bool val)
 {
     KSharedConfig::Ptr kcminputPtr = KSharedConfig::openConfig("kcminputrc");
     KConfigGroup group(kcminputPtr, "Mouse");
@@ -47,7 +50,8 @@ template<> void LibinputSettings::save(QString key, bool val)
     kcminputPtr->sync();
 }
 
-template<> void LibinputSettings::save(QString key, qreal val)
+template<>
+void LibinputSettings::save(QString key, qreal val)
 {
     KSharedConfig::Ptr kcminputPtr = KSharedConfig::openConfig("kcminputrc");
     KConfigGroup group(kcminputPtr, "Mouse");
